.. showtens documentation master file, created by
   sphinx-quickstart on Thu Oct 31 14:07:04 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

showtens Documentation
======================
**showtens** is a package for displaying tensors EASILY. In one line, you can 
view image tensors, whether they are batched or not, grayscale or not.
No need to spend several lines formatting, making into a grid, import matplotlib, etc.
In just one line, your tensor shows up. In just one line, it is saved.

Installation instructions
=========================
TODO

Function use :
===============

.. automodule:: showtens
   :members: show_image, show_video, save_image, save_video, gridify
   :member-order: bysource
   :show-inheritance:



